"""
adapt_with_scopings_container

Autogenerated DPF operator classes.
"""

from __future__ import annotations

from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification
from ansys.dpf.core.config import Config
from ansys.dpf.core.server_types import AnyServerType


class adapt_with_scopings_container(Operator):
    r"""Rescopes/splits a fields container to correspond to a scopings
    container.


    Parameters
    ----------
    field_or_fields_container: FieldsContainer or Field
    scopings_container: ScopingsContainer

    Returns
    -------
    fields_container: FieldsContainer

    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.scoping.adapt_with_scopings_container()

    >>> # Make input connections
    >>> my_field_or_fields_container = dpf.FieldsContainer()
    >>> op.inputs.field_or_fields_container.connect(my_field_or_fields_container)
    >>> my_scopings_container = dpf.ScopingsContainer()
    >>> op.inputs.scopings_container.connect(my_scopings_container)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.scoping.adapt_with_scopings_container(
    ...     field_or_fields_container=my_field_or_fields_container,
    ...     scopings_container=my_scopings_container,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(
        self,
        field_or_fields_container=None,
        scopings_container=None,
        config=None,
        server=None,
    ):
        super().__init__(name="rescope_fc", config=config, server=server)
        self._inputs = InputsAdaptWithScopingsContainer(self)
        self._outputs = OutputsAdaptWithScopingsContainer(self)
        if field_or_fields_container is not None:
            self.inputs.field_or_fields_container.connect(field_or_fields_container)
        if scopings_container is not None:
            self.inputs.scopings_container.connect(scopings_container)

    @staticmethod
    def _spec() -> Specification:
        description = r"""Rescopes/splits a fields container to correspond to a scopings
container.
"""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="field_or_fields_container",
                    type_names=["fields_container", "field"],
                    optional=False,
                    document=r"""""",
                ),
                1: PinSpecification(
                    name="scopings_container",
                    type_names=["scopings_container"],
                    optional=False,
                    document=r"""""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document=r"""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server: AnyServerType = None) -> Config:
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server:
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.

        Returns
        -------
        config:
            A new Config instance equivalent to the default config for this operator.
        """
        return Operator.default_config(name="rescope_fc", server=server)

    @property
    def inputs(self) -> InputsAdaptWithScopingsContainer:
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs:
            An instance of InputsAdaptWithScopingsContainer.
        """
        return super().inputs

    @property
    def outputs(self) -> OutputsAdaptWithScopingsContainer:
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs:
            An instance of OutputsAdaptWithScopingsContainer.
        """
        return super().outputs


class InputsAdaptWithScopingsContainer(_Inputs):
    """Intermediate class used to connect user inputs to
    adapt_with_scopings_container operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.scoping.adapt_with_scopings_container()
    >>> my_field_or_fields_container = dpf.FieldsContainer()
    >>> op.inputs.field_or_fields_container.connect(my_field_or_fields_container)
    >>> my_scopings_container = dpf.ScopingsContainer()
    >>> op.inputs.scopings_container.connect(my_scopings_container)
    """

    def __init__(self, op: Operator):
        super().__init__(adapt_with_scopings_container._spec().inputs, op)
        self._field_or_fields_container = Input(
            adapt_with_scopings_container._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._field_or_fields_container)
        self._scopings_container = Input(
            adapt_with_scopings_container._spec().input_pin(1), 1, op, -1
        )
        self._inputs.append(self._scopings_container)

    @property
    def field_or_fields_container(self) -> Input:
        r"""Allows to connect field_or_fields_container input to the operator.

        Returns
        -------
        input:
            An Input instance for this pin.

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.scoping.adapt_with_scopings_container()
        >>> op.inputs.field_or_fields_container.connect(my_field_or_fields_container)
        >>> # or
        >>> op.inputs.field_or_fields_container(my_field_or_fields_container)
        """
        return self._field_or_fields_container

    @property
    def scopings_container(self) -> Input:
        r"""Allows to connect scopings_container input to the operator.

        Returns
        -------
        input:
            An Input instance for this pin.

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.scoping.adapt_with_scopings_container()
        >>> op.inputs.scopings_container.connect(my_scopings_container)
        >>> # or
        >>> op.inputs.scopings_container(my_scopings_container)
        """
        return self._scopings_container


class OutputsAdaptWithScopingsContainer(_Outputs):
    """Intermediate class used to get outputs from
    adapt_with_scopings_container operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.scoping.adapt_with_scopings_container()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, op: Operator):
        super().__init__(adapt_with_scopings_container._spec().outputs, op)
        self._fields_container = Output(
            adapt_with_scopings_container._spec().output_pin(0), 0, op
        )
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self) -> Output:
        r"""Allows to get fields_container output of the operator

        Returns
        -------
        output:
            An Output instance for this pin.

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.scoping.adapt_with_scopings_container()
        >>> # Get the output from op.outputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """
        return self._fields_container
