"""
assemble_scalars_to_vectors_fc

Autogenerated DPF operator classes.
"""

from __future__ import annotations

from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification
from ansys.dpf.core.config import Config
from ansys.dpf.core.server_types import AnyServerType


class assemble_scalars_to_vectors_fc(Operator):
    r"""Takes three scalar fields container and assembles them as a 3D vector
    fields container.


    Parameters
    ----------
    x: FieldsContainer, optional
    y: FieldsContainer, optional
    z: FieldsContainer, optional

    Returns
    -------
    fields_container: FieldsContainer

    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.utility.assemble_scalars_to_vectors_fc()

    >>> # Make input connections
    >>> my_x = dpf.FieldsContainer()
    >>> op.inputs.x.connect(my_x)
    >>> my_y = dpf.FieldsContainer()
    >>> op.inputs.y.connect(my_y)
    >>> my_z = dpf.FieldsContainer()
    >>> op.inputs.z.connect(my_z)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.utility.assemble_scalars_to_vectors_fc(
    ...     x=my_x,
    ...     y=my_y,
    ...     z=my_z,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, x=None, y=None, z=None, config=None, server=None):
        super().__init__(
            name="assemble_scalars_to_vectors_fc", config=config, server=server
        )
        self._inputs = InputsAssembleScalarsToVectorsFc(self)
        self._outputs = OutputsAssembleScalarsToVectorsFc(self)
        if x is not None:
            self.inputs.x.connect(x)
        if y is not None:
            self.inputs.y.connect(y)
        if z is not None:
            self.inputs.z.connect(z)

    @staticmethod
    def _spec() -> Specification:
        description = r"""Takes three scalar fields container and assembles them as a 3D vector
fields container.
"""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="x",
                    type_names=["fields_container"],
                    optional=True,
                    document=r"""""",
                ),
                1: PinSpecification(
                    name="y",
                    type_names=["fields_container"],
                    optional=True,
                    document=r"""""",
                ),
                2: PinSpecification(
                    name="z",
                    type_names=["fields_container"],
                    optional=True,
                    document=r"""""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document=r"""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server: AnyServerType = None) -> Config:
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server:
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.

        Returns
        -------
        config:
            A new Config instance equivalent to the default config for this operator.
        """
        return Operator.default_config(
            name="assemble_scalars_to_vectors_fc", server=server
        )

    @property
    def inputs(self) -> InputsAssembleScalarsToVectorsFc:
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs:
            An instance of InputsAssembleScalarsToVectorsFc.
        """
        return super().inputs

    @property
    def outputs(self) -> OutputsAssembleScalarsToVectorsFc:
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs:
            An instance of OutputsAssembleScalarsToVectorsFc.
        """
        return super().outputs


class InputsAssembleScalarsToVectorsFc(_Inputs):
    """Intermediate class used to connect user inputs to
    assemble_scalars_to_vectors_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.assemble_scalars_to_vectors_fc()
    >>> my_x = dpf.FieldsContainer()
    >>> op.inputs.x.connect(my_x)
    >>> my_y = dpf.FieldsContainer()
    >>> op.inputs.y.connect(my_y)
    >>> my_z = dpf.FieldsContainer()
    >>> op.inputs.z.connect(my_z)
    """

    def __init__(self, op: Operator):
        super().__init__(assemble_scalars_to_vectors_fc._spec().inputs, op)
        self._x = Input(assemble_scalars_to_vectors_fc._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._x)
        self._y = Input(assemble_scalars_to_vectors_fc._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._y)
        self._z = Input(assemble_scalars_to_vectors_fc._spec().input_pin(2), 2, op, -1)
        self._inputs.append(self._z)

    @property
    def x(self) -> Input:
        r"""Allows to connect x input to the operator.

        Returns
        -------
        input:
            An Input instance for this pin.

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.assemble_scalars_to_vectors_fc()
        >>> op.inputs.x.connect(my_x)
        >>> # or
        >>> op.inputs.x(my_x)
        """
        return self._x

    @property
    def y(self) -> Input:
        r"""Allows to connect y input to the operator.

        Returns
        -------
        input:
            An Input instance for this pin.

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.assemble_scalars_to_vectors_fc()
        >>> op.inputs.y.connect(my_y)
        >>> # or
        >>> op.inputs.y(my_y)
        """
        return self._y

    @property
    def z(self) -> Input:
        r"""Allows to connect z input to the operator.

        Returns
        -------
        input:
            An Input instance for this pin.

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.assemble_scalars_to_vectors_fc()
        >>> op.inputs.z.connect(my_z)
        >>> # or
        >>> op.inputs.z(my_z)
        """
        return self._z


class OutputsAssembleScalarsToVectorsFc(_Outputs):
    """Intermediate class used to get outputs from
    assemble_scalars_to_vectors_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.assemble_scalars_to_vectors_fc()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, op: Operator):
        super().__init__(assemble_scalars_to_vectors_fc._spec().outputs, op)
        self._fields_container = Output(
            assemble_scalars_to_vectors_fc._spec().output_pin(0), 0, op
        )
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self) -> Output:
        r"""Allows to get fields_container output of the operator

        Returns
        -------
        output:
            An Output instance for this pin.

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.assemble_scalars_to_vectors_fc()
        >>> # Get the output from op.outputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """
        return self._fields_container
