"""
fields_container

Autogenerated DPF operator classes.
"""

from __future__ import annotations

from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification
from ansys.dpf.core.config import Config
from ansys.dpf.core.server_types import AnyServerType


class fields_container(Operator):
    r"""Incrementaly merge the input.


    Parameters
    ----------
    input: FieldsContainer

    Returns
    -------
    incremented_result:

    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.utility.fields_container()

    >>> # Make input connections
    >>> my_input = dpf.FieldsContainer()
    >>> op.inputs.input.connect(my_input)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.utility.fields_container(
    ...     input=my_input,
    ... )

    >>> # Get output data
    >>> result_incremented_result = op.outputs.incremented_result()
    """

    def __init__(self, input=None, config=None, server=None):
        super().__init__(
            name="incremental::merge::fields_container", config=config, server=server
        )
        self._inputs = InputsFieldsContainer(self)
        self._outputs = OutputsFieldsContainer(self)
        if input is not None:
            self.inputs.input.connect(input)

    @staticmethod
    def _spec() -> Specification:
        description = r"""Incrementaly merge the input.
"""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="input",
                    type_names=["fields_container"],
                    optional=False,
                    document=r"""""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="incremented_result",
                    optional=False,
                    document=r"""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server: AnyServerType = None) -> Config:
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server:
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.

        Returns
        -------
        config:
            A new Config instance equivalent to the default config for this operator.
        """
        return Operator.default_config(
            name="incremental::merge::fields_container", server=server
        )

    @property
    def inputs(self) -> InputsFieldsContainer:
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs:
            An instance of InputsFieldsContainer.
        """
        return super().inputs

    @property
    def outputs(self) -> OutputsFieldsContainer:
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs:
            An instance of OutputsFieldsContainer.
        """
        return super().outputs


class InputsFieldsContainer(_Inputs):
    """Intermediate class used to connect user inputs to
    fields_container operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.fields_container()
    >>> my_input = dpf.FieldsContainer()
    >>> op.inputs.input.connect(my_input)
    """

    def __init__(self, op: Operator):
        super().__init__(fields_container._spec().inputs, op)
        self._input = Input(fields_container._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._input)

    @property
    def input(self) -> Input:
        r"""Allows to connect input input to the operator.

        Returns
        -------
        input:
            An Input instance for this pin.

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.fields_container()
        >>> op.inputs.input.connect(my_input)
        >>> # or
        >>> op.inputs.input(my_input)
        """
        return self._input


class OutputsFieldsContainer(_Outputs):
    """Intermediate class used to get outputs from
    fields_container operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.fields_container()
    >>> # Connect inputs : op.inputs. ...
    >>> result_incremented_result = op.outputs.incremented_result()
    """

    def __init__(self, op: Operator):
        super().__init__(fields_container._spec().outputs, op)
        self._incremented_result = Output(fields_container._spec().output_pin(0), 0, op)
        self._outputs.append(self._incremented_result)

    @property
    def incremented_result(self) -> Output:
        r"""Allows to get incremented_result output of the operator

        Returns
        -------
        output:
            An Output instance for this pin.

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.fields_container()
        >>> # Get the output from op.outputs. ...
        >>> result_incremented_result = op.outputs.incremented_result()
        """
        return self._incremented_result
